.. _modules_abstract_model:

Abstract Model
=====================
This is the common model class

.. module:: pyorbit.models.abstract_model

Add explanation

.. automodule:: pyorbit.models.abstract_model
   :members:
